@@ -29,8 +29,7 @@ pub type Result<T> = std::result::Result<T, Error>;
 #[cfg(test)]
 mod tests {
 
-
-use crate::*;
+	use crate::*;
 
     #[test]
     fn test() {
@@ -54,7 +53,7 @@ use crate::*;
 
 		println!("{error}");
 
-		println!("{span}")
+		println!("{span:?}")
 
 	}
 
