@@ -221,7 +221,19 @@ impl Ord for Span {
 
 	fn cmp(&self, other: &Self) -> std::cmp::Ordering {
 		
-		self.start.index.cmp(&other.start.index)
+		let start_ordering = self.start.index.cmp(&other.start.index);
+
+		if let std::cmp::Ordering::Equal = start_ordering {
+
+			self.end.index.cmp(&other.end.index)
+
+		}
+
+		else {
+
+			start_ordering
+
+		}
 
 	}
 
@@ -230,9 +242,9 @@ impl Ord for Span {
 impl PartialOrd for Span {
 
 	fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+	
+		Some(self.cmp(&other))
 		
-		self.start.index.partial_cmp(&other.start.index)
-
 	}
 
 }
